================
jwt_helper
================

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://pypi.org/project/black

.. image:: https://app.codacy.com/project/badge/Grade/bfc97f9667f64c4a9f7d26f937393260
    :target: https://www.codacy.com/gh/bad-microservices/jwt_helper/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=bad-microservices/jwt_helper&amp;utm_campaign=Badge_Grade

.. image:: https://badge.fury.io/py/jwt_helper.svg
    :target: https://badge.fury.io/py/jwt_helper

.. image:: https://github.com/bad-microservices/jwt_helper/actions/workflows/documentation.yaml/badge.svg
   :target: https://github.com/bad-microservices/jwt_helper/actions?query=workflow:Docs

.. image:: https://github.com/bad-microservices/jwt_helper/actions/workflows/pypi_upload.yaml/badge.svg
    :target: https://github.com/bad-microservices/jwt_helper/actions?query=workflow:pypi

Introduction
=============

jwt_helper aims to be a simple to use wrapper around `pyjwt` with some predefined functions to make life easier.
